@@ -1,6 +1,6 @@
 /**
  * @file  cfgfile.c
- * @copyright Copyright (C) 2019 Michał Bąbik
+ * @copyright Copyright (C) 2019-2020 Michał Bąbik
  *
  * This file is part of Wall Changer.
  *
@@ -61,15 +61,20 @@
  */
 /*----------------------------------------------------------------------------*/
 static int check_permissions             (const char *s_name,
-                                          const int   i_mode);
+                                          const int   i_mode)
+                                          __attribute__ ((nonnull (1)));
 
-static int check_file_permissions        (const char *s_file);
+static int check_file_permissions        (const char *s_file)
+                                          __attribute__ ((nonnull (1)));
 
-static int check_dir_permissions         (const char *s_dir);
+static int check_dir_permissions         (const char *s_dir)
+                                          __attribute__ ((nonnull (1)));
 
-static int check_dir_premissions_create  (const char *s_dir);
+static int check_dir_premissions_create  (const char *s_dir)
+                                          __attribute__ ((nonnull (1)));
 
-static int check_file_premissions_create (const char *s_file);
+static int check_file_premissions_create (const char *s_file)
+                                          __attribute__ ((nonnull (1)));
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Check permissions, existence of file or directory. 
@@ -80,10 +85,8 @@ check_permissions (const char *s_name,
 {
     /* check if file/dir exists */
     if (access (s_name, F_OK) == 0) {
-
         /* check permissions */
         if (access (s_name, i_mode) != 0) {
-
             fputs (s_name, stderr);
             fputs (" Bad file / directory permissions\n", stderr);
             return ERR_FILE;
@@ -135,7 +138,6 @@ check_dir_premissions_create (const char *s_dir)
     }
     /* If directory does not exist */
     else if (i_res == ERR_FILE_EX) {
-
         /* try to create it */
         i_res2 = mkdir (s_dir, 0700);
 
@@ -168,7 +170,6 @@ check_file_premissions_create (const char *s_file)
     }
     /* If file does not exist */
     else if (i_res == ERR_FILE_EX) {
-
         /* try to create it */
         f_file = fopen(s_file, "a+");
 
@@ -254,19 +255,15 @@ check_config_path_file (int *i_err)
 int
 set_config_file_path (char *s_path)
 {
-    int i_res = ERR_OK;
-
+    int   i_res = ERR_OK;
     char *s_cfg = check_config_path_file (&i_res);
 
     if (i_res != ERR_OK) {
         free (s_cfg);
         return i_res;
     }
-
     strncpy (s_path, s_cfg, 255);
-
     free (s_cfg);
-
     return i_res;
 }
 /*----------------------------------------------------------------------------*/
